#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Sep  9 08:36:33 2018
Visual Tracking with particle filter
@author: thierrychateau
"""
import cv2
import os
import numpy as np
import argparse
def main():
    # construct the argument parser and parse the arguments
    ap = argparse.ArgumentParser()
    ap.add_argument("-v", "--video", type=str,
        help="path to input video file")
    ap.add_argument("-t", "--tracker", type=str, default="kcf",
        help="OpenCV object tracker type")
    args = vars(ap.parse_args())
    Basename = 'images/nascar/nascar'   #basename of image files
    ext = 'png' # extension used
    FirstImage = 1 # first image of the sequence
    LastImage = 150 # last  image of the sequence
    step = 1 #step between 2 images 
    first = 1 # Flag for first frame
    # initialize a dictionary that maps strings to their corresponding
    # OpenCV object tracker implementations
    OPENCV_OBJECT_TRACKERS = {
        "csrt": cv2.TrackerCSRT_create,
        "kcf": cv2.TrackerKCF_create,
        "boosting": cv2.TrackerBoosting_create,
        "mil": cv2.TrackerMIL_create,
        "tld": cv2.TrackerTLD_create,
        "medianflow": cv2.TrackerMedianFlow_create,
        "mosse": cv2.TrackerMOSSE_create }
    # initialize OpenCV's special multi-object tracker
    trackers = cv2.MultiTracker_create() 
    for i in range(FirstImage, LastImage,step):
        filename = "%s%0.5d.%s" % (Basename,i,ext)
        print(filename)
        frame = cv2.imread(filename)
        if first :
            while True :
                cv2.imshow('frame',frame)
                key = cv2.waitKey(1) & 0xFF
                # if the 's' key is selected, we are going to "select" a bounding
                # box to track
                if key == ord("s"):
                    # select the bounding box of the object we want to track (make
                    # sure you press ENTER or SPACE after selecting the ROI)
                    box = cv2.selectROI("Frame", frame, fromCenter=False, showCrosshair=True)
                    # create a new object tracker for the bounding box and add it
                    # to our multi-object tracker
                    tracker = OPENCV_OBJECT_TRACKERS[args["tracker"]]()
                    trackers.add(tracker, frame, box)
                # if the `q` key was pressed, break from the loop
                elif key == ord("q"):
                    cv2.destroyAllWindows()
                    break
            first = 0
        else : 
            # grab the updated bounding box coordinates (if any) for each
            # object that is being tracked
            (success, boxes) = trackers.update(frame)
            # loop over the bounding boxes and draw then on the frame
            for box in boxes:
                (x, y, w, h) = [int(v) for v in box]
                cv2.rectangle(frame, (x, y), (x + w, y + h), (0, 255, 0), 2)
            cv2.imshow('frame',frame)
            if cv2.waitKey(1) & 0xFF == ord('q'):
                break
if __name__ == "__main__":
    # execute only if run as a script
    main()
    

